@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use autodie;
 
-our $VERSION = '0.08_01'; # TRIAL VERSION
+our $VERSION = '0.08_02'; # TRIAL VERSION
 
 use Exporter;
 use parent 'Exporter';
@@ -384,7 +384,7 @@ Date::Easy::Datetime - easy datetime class
 
 =head1 VERSION
 
-This document describes version 0.08_01 of Date::Easy::Datetime.
+This document describes version 0.08_02 of Date::Easy::Datetime.
 
 =head1 SYNOPSIS
 
@@ -748,7 +748,7 @@ it was going to do.)
 
 There is a bug in L<Time::ParseDate> which causes epoch seconds to be one hour off in certain
 specific circumstances.  Please note that you will I<not> hit this bug if the string you pass to
-L</datetime> has I<any> of the following characteristicts:
+L</datetime($string)> has I<any> of the following characteristicts:
 
 =over 4
 
